summaryrefslogtreecommitdiff
path: root/tests/configs
diff options
context:
space:
mode:
Diffstat (limited to 'tests/configs')
-rw-r--r--tests/configs/tgen-simple-mem.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/configs/tgen-simple-mem.py b/tests/configs/tgen-simple-mem.py
index 1a95acb54..ae7364214 100644
--- a/tests/configs/tgen-simple-mem.py
+++ b/tests/configs/tgen-simple-mem.py
@@ -46,8 +46,8 @@ cpu = TrafficGen(config_file = "tests/quick/se/70.tgen/tgen-simple-mem.cfg")
system = System(cpu = cpu, physmem = SimpleMemory(),
membus = NoncoherentBus(clock="1GHz", width = 16))
-# add a communication monitor
-system.monitor = CommMonitor()
+# add a communication monitor, and also trace all the packets
+system.monitor = CommMonitor(trace_file = "monitor.ptrc.gz")
# connect the traffic generator to the bus via a communication monitor
system.cpu.port = system.monitor.slave